package com.hungraim.ltc.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.hungraim.ltc.pojo.entity.assessment.ChRefuseReason;
import com.hungraim.ltc.pojo.entity.disable.ChCfgSrvDisableLevel;
import com.hungraim.ltc.pojo.vo.assessment.*;
import com.hungraim.ltc.util.Result;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 失能评定Service
 *
 * @author czz
 */
@Service
public interface TaskService {

    /**
     * 评定任务分配列表
     *
     * @param organId       适用机构代码
     * @param provincial    所在省
     * @param city          所在市
     * @param area          所在区域
     * @param street        所在街道
     * @param realName      失能人员姓名
     * @param certiCode     失能人员身份证号码
     * @param taskName      评定人员姓名
     * @param taskTel       评定人员手机号码
     * @param daysRemaining 评定剩余天数
     * @param status        任务状态
     * @param isReturn      是否退回
     * @param pageNum       当前页
     * @param pageSize      每页几条数据
     */
    IPage<TaskDistributionVO> taskDistributionList(String organId, String provincial, String city,
                                                   String street, String realName, String certiCode, String taskName, String taskTel,
                                                   String daysRemaining, String status, String isReturn, String area,
                                                   int pageNum, int pageSize);

    /**
     * 评定报告录入列表
     *
     * @param name      失能人员姓名
     * @param certiCode 失能人员身份证号码
     * @param tel       失能人员手机号码
     */
    List<TaskReportVO> taskReportList(String name, String certiCode, String tel);

    List<AprEmpVO> aprEmpList(String organName, String name, String tel, String groupLeader);

    Result<Object> addReport(Integer taskId, Integer person1, Integer person2, Integer person3, Date evaluateTime, Integer disableLevelId, String polNo, String remark);

    void updateReport(Integer reportId, Integer person1, Integer person2, Integer person3, Date evaluateDate, Integer disableLevelId, String polNo, String remark);

    Result<Object> allotTask(String taskId, String empId);

    List<TaskGroupVO> taskGroupList(String name, String certiCode, String tel);

    Result<Object> taskGroup(Integer pushId, Integer status, Integer refuseReason, String refuseRemark);

    List<ChCfgSrvDisableLevel> cfgSrvDisableLevelList();

    List<PersonInfoVO> personInfoList(String reportId);

    List<TaskGroupInfoVO> taskGroupInfoList(String groupNumber);

    Result<Object> taskGroupByGroup(String groupNumber, Integer status, Integer refuseReason, String refuseRemark);

    TaskGroupInfoListInfoVO taskGroupInfoListInfo(String pushId);

    List<AllotTaskHisVO> allotTaskHisList();

    Result<Object> updatePushTimeAndRemark(String pushId, Date timeDate, String remark);

    List<ChRefuseReason> refuseReasonList();
}
