package com.hungraim.ltc.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.dao.*;
import com.hungraim.ltc.pojo.entity.assessment.*;
import com.hungraim.ltc.pojo.entity.disable.ChCfgSrvDisableLevel;
import com.hungraim.ltc.pojo.entity.disable.ChDisableInfo;
import com.hungraim.ltc.pojo.vo.assessment.*;
import com.hungraim.ltc.service.TaskService;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.SerialNumberUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * @author czz
 */
@Service
public class TaskServiceImpl implements TaskService {

    @Autowired
    private TaskMapper taskMapper;
    @Autowired
    private AprEmpMapper aprEmpMapper;
    @Autowired
    private AprReportMapper aprReportMapper;
    @Autowired
    private TaskEmpMapper taskEmpMapper;
    @Autowired
    private AprPersonInfoMapper personInfoMapper;
    @Autowired
    private TaskPushMapper taskPushMapper;
    @Autowired
    private TaskPushHisMapper taskPushHisMapper;
    @Autowired
    private CfgSrvDisableLevelMapper cfgSrvDisableLevelMapper;
    @Autowired
    private DisableInfoMapper disableInfoMapper;
    @Autowired
    private RefuseReasonMapper refuseReasonMapper;

    @Override
    public IPage<TaskDistributionVO> taskDistributionList(String organId, String provincial, String city,
                                                          String street, String realName, String certiCode, String taskName, String taskTel,
                                                          String daysRemaining, String status, String isReturn, String area,
                                                          int pageNum, int pageSize) {
        List<String> organIds = null;
        if (StrUtil.isNotBlank(organId)) {
            organIds = Arrays.asList(organId.split(","));
        }
        return taskMapper.taskDistributionList(new Page<>(pageNum, pageSize), organIds, provincial, city,
                street, realName, certiCode, taskName, taskTel, daysRemaining, status, isReturn, area);
    }

    @Override
    public List<TaskReportVO> taskReportList(String name, String certiCode, String tel) {
        return taskMapper.taskReportList(name, certiCode, tel);
    }

    @Override
    public List<AprEmpVO> aprEmpList(String organName, String name, String tel, String groupLeader) {
        return taskMapper.aprEmpList(organName, name, tel, groupLeader);
    }

    @Override
    public Result<Object> addReport(Integer taskId, Integer person1, Integer person2, Integer person3, Date evaluateTime, Integer disableLevelId, String polNo, String remark) {
        ChAprTask task = taskMapper.selectById(taskId);
        if (task != null) {
            return Result.failed("已存在的评定任务报告!");
        }
        ChAprReport report = new ChAprReport();
        report.setTaskId(taskId);
        report.setEffTime(new Date());
        report.setRemark(remark);
        report.setDisableLevelId(disableLevelId);
        report.setPolNo(polNo);
        report.setStatus(0);
        report.setEvaluateTime(evaluateTime);
        aprReportMapper.insert(report);
        //person1
        ChAprPersonInfo person1Info = new ChAprPersonInfo();
        person1Info.setReportId(report.getReportId());
        person1Info.setEmpId(person1);
        person1Info.setFcd(new Date());
        personInfoMapper.insert(person1Info);
        if (person2 != null) {
            ChAprPersonInfo personInfo = new ChAprPersonInfo();
            personInfo.setReportId(report.getReportId());
            personInfo.setEmpId(person1);
            personInfo.setFcd(new Date());
            personInfoMapper.insert(personInfo);
        }
        if (person3 != null) {
            ChAprPersonInfo personInfo = new ChAprPersonInfo();
            personInfo.setReportId(report.getReportId());
            personInfo.setEmpId(person1);
            personInfo.setFcd(new Date());
            personInfoMapper.insert(personInfo);
        }
        return Result.success();
    }

    @Override
    public void updateReport(Integer reportId, Integer person1, Integer person2, Integer person3, Date evaluateDate, Integer disableLevelId, String polNo, String remark) {
        //update鉴定报告
        ChAprReport chAprReport = aprReportMapper.selectById(reportId);
        chAprReport.setDisableLevelId(disableLevelId);
        chAprReport.setPolNo(polNo);
        chAprReport.setRemark(remark);
        chAprReport.setEvaluateTime(evaluateDate);
        aprReportMapper.updateById(chAprReport);
        //修改鉴定报告人员(有就update,没有就insert)
        List<ChAprPersonInfo> personInfos = personInfoMapper.selectList(new QueryWrapper<ChAprPersonInfo>().eq("report_id", reportId).orderByDesc("info_id"));
        if (person1 != null) {
            if (personInfos.size() >= 1) {
                ChAprPersonInfo personInfo = personInfos.get(0);
                personInfo.setEmpId(person1);
                personInfoMapper.updateById(personInfo);
            } else {
                ChAprPersonInfo personInfo = new ChAprPersonInfo();
                personInfo.setReportId(chAprReport.getReportId());
                personInfo.setEmpId(person1);
                personInfo.setFcd(new Date());
                personInfoMapper.insert(personInfo);
            }
        }
        if (person2 != null) {
            if (personInfos.size() >= 2) {
                ChAprPersonInfo personInfo = personInfos.get(1);
                personInfo.setEmpId(person2);
                personInfoMapper.updateById(personInfo);
            } else {
                ChAprPersonInfo personInfo = new ChAprPersonInfo();
                personInfo.setReportId(chAprReport.getReportId());
                personInfo.setEmpId(person2);
                personInfo.setFcd(new Date());
                personInfoMapper.insert(personInfo);
            }
        }
        if (person3 != null) {
            if (personInfos.size() >= 3) {
                ChAprPersonInfo personInfo = personInfos.get(2);
                personInfo.setEmpId(person3);
                personInfoMapper.updateById(personInfo);
            } else {
                ChAprPersonInfo personInfo = new ChAprPersonInfo();
                personInfo.setReportId(chAprReport.getReportId());
                personInfo.setEmpId(person3);
                personInfo.setFcd(new Date());
                personInfoMapper.insert(personInfo);
            }
        }
    }

    @Override
    public Result<Object> allotTask(String taskId, String empId) {
        ChAprEmp chAprEmp = aprEmpMapper.selectById(empId);
        if (chAprEmp == null || chAprEmp.getGroupLeader() == null || chAprEmp.getGroupLeader() != 0) {
            //不是组长
            return Result.failed("评定人员必须是组长!");
        }
        String[] taskIds = taskId.split(",");
        //任务分配日期
        Date assignTime = new Date();
        for (String id : taskIds) {
            ChAprTask task = taskMapper.selectById(id);
            if (task == null) {
                return Result.failed("无效的taskId!");
            }
            //更新评定任务信息
            task.setAprEmpId(Integer.parseInt(empId));
            task.setAssignTime(assignTime);
            taskMapper.updateById(task);
            //更新失能人员信息
            ChDisableInfo chDisableInfo = disableInfoMapper.selectById(task.getDisableInfoId());
            chDisableInfo.setLastTaskId(task.getTaskId());
            disableInfoMapper.updateById(chDisableInfo);
            //生成组
            ChAprTaskPush taskPush = new ChAprTaskPush();
            taskPush.setAssignTime(new Date());
            taskPush.setGroupNumber(SerialNumberUtils.getSerialNumber(empId));
            taskPush.setTaskId(Long.parseLong(id));
            taskPush.setEmpId(Long.parseLong(empId));
            taskPush.setStatus((short) 1);
            taskPush.setIsManual((short) 1);
            //生成分组历史
            ChAprTaskPushHis pushHis = new ChAprTaskPushHis();
            BeanUtils.copyProperties(taskPush, pushHis);
            //插入分组数据
            taskPushMapper.insert(taskPush);
            taskPushHisMapper.insert(pushHis);
        }
        return Result.success();
    }

    @Override
    public List<TaskGroupVO> taskGroupList(String name, String certiCode, String tel) {
        return taskMapper.taskGroupList(name, certiCode, tel);
    }

    @Override
    public Result<Object> taskGroup(Integer pushId, Integer status, Integer refuseReason, String refuseRemark) {
        ChAprTaskPush chAprTaskPush = taskPushMapper.selectById(pushId);
        if (chAprTaskPush == null) {
            return Result.failed("不存在的组!");
        }
        chAprTaskPush.setStatus(status.shortValue());
        if (status == 4 || status == 5 || status == 0) {
            chAprTaskPush.setRefuseReason(refuseReason.shortValue());
            chAprTaskPush.setRefuseRemark(refuseRemark);
        }
        taskPushMapper.updateById(chAprTaskPush);
        return Result.success();
    }

    @Override
    public List<ChCfgSrvDisableLevel> cfgSrvDisableLevelList() {
        return cfgSrvDisableLevelMapper.selectList(new QueryWrapper<>());
    }

    @Override
    public List<PersonInfoVO> personInfoList(String reportId) {
        return taskMapper.personInfoList(reportId);
    }

    @Override
    public List<TaskGroupInfoVO> taskGroupInfoList(String groupNumber) {
        return taskMapper.taskGroupInfoList(groupNumber);
    }

    @Override
    public Result<Object> taskGroupByGroup(String groupNumber, Integer status, Integer refuseReason, String refuseRemark) {
        List<ChAprTaskPush> pushList = taskPushMapper.selectList(new QueryWrapper<ChAprTaskPush>().eq("group_number", groupNumber));
        if (pushList == null || pushList.size() <= 0) {
            return Result.failed("不存在的组!");
        }
        short status1 = pushList.get(0).getStatus();
        for (ChAprTaskPush push : pushList) {
            if (status1 != push.getStatus()) {
                return Result.failed("该组状态不一致,不可整组操作!");
            }
        }
        for (ChAprTaskPush push : pushList) {
            //更新任务组状态
            push.setStatus(status.shortValue());
            if (status == 4 || status == 5 || status == 0) {
                push.setRefuseReason(refuseReason.shortValue());
                push.setRefuseRemark(refuseRemark);
            }
            taskPushMapper.updateById(push);
            //更新评定任务状态
            ChAprTask chAprTask = taskMapper.selectById(push.getTaskId());
            chAprTask.setTaskStatus(status);
        }
        return Result.success();
    }

    @Override
    public TaskGroupInfoListInfoVO taskGroupInfoListInfo(String pushId) {
        return taskMapper.taskGroupInfoListInfo(pushId);
    }

    @Override
    public List<AllotTaskHisVO> allotTaskHisList() {
        return taskMapper.allotTaskHisList();
    }

    @Override
    public Result<Object> updatePushTimeAndRemark(String pushId, Date timeDate, String remark) {
        ChAprTaskPush chAprTaskPush = taskPushMapper.selectById(pushId);
        if (chAprTaskPush == null) {
            return Result.failed("无效的分组id!");
        }
        chAprTaskPush.setTime(timeDate);
        chAprTaskPush.setRefuseRemark(remark);
        int i = taskPushMapper.updateById(chAprTaskPush);
        if (i <= 0) {
            return Result.failed("更新失败!");
        }
        return Result.success();
    }

    @Override
    public List<ChRefuseReason> refuseReasonList() {
        return refuseReasonMapper.selectList(new QueryWrapper<>());
    }
}