package com.hungraim.ltc.governance.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.vo.governance.ProgramSetListVo;
import com.hungraim.ltc.pojo.vo.governance.SvrProgramListVo;
import com.hungraim.ltc.governance.service.SrvProgramService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/api.governance/srvProgram")
@Slf4j
public class SrvProgramController {

    @Autowired
    private SrvProgramService srvProgramService;

    /**
     * 获取方案详情
     *
     * @param programId
     * @return
     */
    @RequestMapping("/{programId}")
    public Result getSrvProgram(@PathVariable("programId") Long programId) {

        return Result.success();
    }

    /**
     * 个人照护方案查询列表
     *
     * @param srvOrganId    服务机构id
     * @param realName      失能人员姓名
     * @param realTel       失能人员手机号
     * @param programStatus 服务方案状态
     * @return 返回列表
     */
    @RequestMapping("/programList")
    public Result getProgramList(Long srvOrganId, String realName, String realTel, String programStatus, Integer pageNum, Integer pageSize) {
        if (pageNum == null || pageNum < 1) {
            return Result.failed("参数错误");
        }
        if (pageSize == null || pageSize < 1) {
            pageSize = 10;
        }
        Page<SvrProgramListVo> page = new Page<>(pageNum, pageSize);
        page = srvProgramService.getProgramList(page, srvOrganId, realName, realTel, programStatus);
        return Result.success(page);
    }

    /**
     * 个人照护方案列表查询
     *
     * @param pageNum     页码
     * @param pageSize    每页大小
     * @param disabInfoId 失能人员id
     * @param srvOrganId  服务机构id
     * @return 返回个人照护方案列表
     */
    @RequestMapping("/programSetList")
    public Result getProgramSetList(Integer pageNum, Integer pageSize, Long disabInfoId, Long srvOrganId) {
        if (pageNum == null || pageNum < 1 || disabInfoId == null || disabInfoId == 0 || srvOrganId == null || srvOrganId == 0) {
            return Result.failed("参数错误");
        }
        if (pageSize == null || pageSize < 1) {
            pageSize = 10;
        }
        Page<ProgramSetListVo> page = new Page<>(pageNum, pageSize);
        page = srvProgramService.getProgramSetList(page, disabInfoId, srvOrganId);
        return Result.success(page);
    }
}
